summaryrefslogtreecommitdiffstats
path: root/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
diff options
context:
space:
mode:
authorChuck Atkins <chuck.atkins@kitware.com>2017-05-15 18:06:29 (GMT)
committerChuck Atkins <chuck.atkins@kitware.com>2017-05-29 17:51:45 (GMT)
commite556f1b909a910f7124bd26f82e4b42dd2142c17 (patch)
tree6077a5aa10d408d2b00e20b2993e5bb87cfc20c6 /Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
parent20ffa14708e5e1b324ac954fd06a1415b9398b7c (diff)
downloadCMake-e556f1b909a910f7124bd26f82e4b42dd2142c17.zip
CMake-e556f1b909a910f7124bd26f82e4b42dd2142c17.tar.gz
CMake-e556f1b909a910f7124bd26f82e4b42dd2142c17.tar.bz2
CompileFeatures: Makes tests work with meta-feature only
Diffstat (limited to 'Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake')
-rw-r--r--Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake5
1 files changed, 3 insertions, 2 deletions
diff --git a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
index 2d14a9e..b24a680 100644
--- a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
+++ b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
@@ -6,9 +6,10 @@ add_library(empty3 INTERFACE)
target_compile_features(empty3 INTERFACE cxx_std_11)
target_link_libraries(empty1
# When starting, $<COMPILE_FEATURES:cxx_auto_type> is '0', so 'freeze' the
# CXX_STANDARD at 98 during computation.
- $<$<COMPILE_FEATURES:cxx_auto_type>:empty2>
+ $<$<COMPILE_FEATURES:cxx_std_11>:empty2>
+
# This would add cxx_std_11, but that would require CXX_STANDARD = 11,
# which is not allowed after freeze. Report an error.
empty3
@@ -6,9 +6,10 @@ add_library(empty3 INTERFACE)
target_compile_features(empty3 INTERFACE cxx_std_11)
target_link_libraries(empty1
- # When starting, $<COMPILE_FEATURES:cxx_auto_type> is '0', so 'freeze' the
+ # When starting, $<COMPILE_FEATURES:cxx_std_11> is '0', so 'freeze' the
# CXX_STANDARD at 98 during computation.